# ConSys [![Build Status](https://app.travis-ci.com/kosyachniy/consys.svg?branch=main)](https://app.travis-ci.com/kosyachniy/consys)
Object-oriented programming control system in Python [Base Object Model]

## Submodules
Module | Description
---|----
` consys ` | ORM for Python & MongoDB
` consys.handlers ` | Ready to use handlers for ORM
` consys.files ` | File uploading system
` consys.types ` | Type checking system
` consys.error ` | Set of errors

[PyPI](https://pypi.org/project/consys/)
